#include "xcframe.h"

XCframe_Config XCframe_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12d0000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12d2000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12e4000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12e6000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12e8000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12ea000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12ec000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12d4000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12d6000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12d8000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12da000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12dc000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12de000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12e0000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12e2000 /* reg */
	},
	{
		"xlnx,psv-pmc-cfi-cframe-1.0", /* compatible */
		0xf12ee000 /* reg */
	},
	 {
		 NULL
	}
};